"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.fireInputEventIfNeeded = fireInputEventIfNeeded;

var _dom = require("@testing-library/dom");

var _utils = require("../../utils");

function fireInputEventIfNeeded({
  currentElement,
  newValue,
  newSelectionStart,
  eventOverrides
}) {
  const el = currentElement();
  const prevValue = (0, _utils.getValue)(el);

  if (el && !isReadonly(el) && !(0, _utils.isClickableInput)(el) && newValue !== prevValue) {
    if ((0, _utils.isContentEditable)(el)) {
      _dom.fireEvent.input(el, {
        target: {
          textContent: newValue
        },
        ...eventOverrides
      });
    } else {
      _dom.fireEvent.input(el, {
        target: {
          value: newValue
        },
        ...eventOverrides
      });
    }

    setSelectionRangeAfterInput(el, newValue, newSelectionStart);
  }

  return {
    prevValue
  };
}

function isReadonly(element) {
  return (0, _utils.isElementType)(element, ['input', 'textarea'], {
    readOnly: true
  });
}

function setSelectionRangeAfterInput(element, newValue, newSelectionStart) {
  // if we *can* change the selection start, then we will if the new value
  // is the same as the current value (so it wasn't programatically changed
  // when the fireEvent.input was triggered).
  // The reason we have to do this at all is because it actually *is*
  // programmatically changed by fireEvent.input, so we have to simulate the
  // browser's default behavior
  const value = (0, _utils.getValue)(element); // don't apply this workaround on elements that don't necessarily report the visible value - e.g. number

  if (value === newValue || value === '' && (0, _utils.hasUnreliableEmptyValue)(element)) {
    (0, _utils.setSelectionRange)(element, newSelectionStart, newSelectionStart);
  } else {
    // If the currentValue is different than the expected newValue and we *can*
    // change the selection range, than we should set it to the length of the
    // currentValue to ensure that the browser behavior is mimicked.
    (0, _utils.setSelectionRange)(element, value.length, value.length);
  }
}